@@ -1,13 +1,14 @@
 package Catalyst::Controller::HTML::FormFu::Action::FormConfig;
-{
-  $Catalyst::Controller::HTML::FormFu::Action::FormConfig::VERSION = '1.00';
-}
 
 use strict;
-use warnings;
-use base qw( Catalyst::Controller::HTML::FormFu::ActionBase::Form );
 
+our $VERSION = '2.01'; # VERSION
+
+use Moose;
 use Config::Any;
+use namespace::autoclean;
+
+extends 'Catalyst::Controller::HTML::FormFu::ActionBase::Form';
 
 sub execute {
     my $self = shift;
