@@ -1,23 +1,25 @@
 package HTML::FormFu::Plugin::RequestToken;
-{
-  $HTML::FormFu::Plugin::RequestToken::VERSION = '1.00';
-}
+
+use strict;
+
+our $VERSION = '2.01'; # VERSION
+
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Plugin';
 
-has context         => ( is => 'rw', traits  => ['Chained'] );
-has field_name      => ( is => 'rw', traits  => ['Chained'] );
-has session_key     => ( is => 'rw', traits  => ['Chained'] );
-has expiration_time => ( is => 'rw', traits  => ['Chained'] );
+has context         => ( is => 'rw', traits  => ['FormFuChained'] );
+has field_name      => ( is => 'rw', traits  => ['FormFuChained'] );
+has session_key     => ( is => 'rw', traits  => ['FormFuChained'] );
+has expiration_time => ( is => 'rw', traits  => ['FormFuChained'] );
 
 sub process {
     my ($self) = @_;
-    
+
     return if $self->form->get_all_element( { name => $self->field_name } );
-    
+
     my $c = $self->form->stash->{'context'};
-    
+
     $self->form->elements( [ {
                 type            => 'RequestToken',
                 name            => $self->field_name,
